@@ -119,6 +119,10 @@ class Certificate(BrowserView):
     def session_url(self):
         return self.webhelpers.traversed_session.absolute_url()
 
+    @property
+    def tool_name(self):
+        return self.webhelpers.tool_name
+
     @property
     @memoize
     def certificate_json(self):
@@ -185,6 +189,10 @@ class PublicCertificate(BrowserView):
         except Exception:
             return None
 
+    @property
+    def tool_name(self):
+        return self.survey.Title() if self.survey else ""
+
     @property
     @memoize
     def language(self):
