@@ -1,6 +1,5 @@
 # coding=utf-8
 from euphorie.client import model
-from five import grok
 from osha.oira.client import model as oiramodel
 from sqlalchemy import sql
 from z3c.saconfig import Session
@@ -10,7 +9,6 @@ import htmllib
 
 
 pl_message = MessageFactory("plonelocales")
-grok.templatedir("templates")
 
 
 NAME_TO_PHASE = {
