@@ -1,15 +1,13 @@
 #  -* coding: utf8 *-
 from euphorie.client import model
+from euphorie.client.browser.publish import EnableCustomRisks
 from euphorie.client.country import IClientCountry
-from euphorie.client.publish import EnableCustomRisks
 from euphorie.client.sector import IClientSector
 from euphorie.content.survey import ISurvey
 from euphorie.deployment.upgrade.utils import TableExists
 from osha.oira import _
 from plone import api
 from plone.dexterity import utils
-from z3c.appconfig.interfaces import IAppConfig
-from z3c.appconfig.utils import asBool
 from z3c.saconfig import Session
 from zope.component.hooks import getSite
 from zope.sqlalchemy import datamanager
@@ -17,7 +15,6 @@ from zope.sqlalchemy import datamanager
 import datetime
 import logging
 import transaction
-import zope.component
 
 
 log = logging.getLogger(__name__)
@@ -172,8 +169,7 @@ def reset_surveygroup_obsolete(context):
 
 def enable_custom_risks_on_all_modules(context):
     """ """
-    appconfig = zope.component.getUtility(IAppConfig)
-    if not asBool(appconfig["euphorie"].get("allow_user_defined_risks")):
+    if not api.portal.get_registry_record("euphorie.allow_user_defined_risks"):
         log.warning(
             "Custom risks are not enabled. Set 'allow_user_defined_risks' to "
             "true in euphorie.ini for enabling them."
